@@ -3,8 +3,6 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
- * 
  * This file contains Original Code and/or Modifications of Original Code
  * as defined in and that are subject to the Apple Public Source License
  * Version 2.0 (the 'License'). You may not use this file except in
@@ -23,22 +21,19 @@
  * @APPLE_LICENSE_HEADER_END@
  */
 
-/* Initialize the "_cpu_capabilities" vector on Intel processors. */
-
-#include <sys/sysctl.h>
-#include <mach/message.h>
-#include <mach/mach_types.h>
-#include <mach/host_info.h>
+/* Initialize the "_cpu_capabilities" vector on x86 processors. */
 
 #define	_APPLE_API_PRIVATE
 #include <machine/cpu_capabilities.h>
 #undef	_APPLE_API_PRIVATE
 
+extern int _get_cpu_capabilities(void);
+
 int _cpu_has_altivec = 0;     // DEPRECATED
+int _cpu_capabilities = 0;
 
 __private_extern__ void
 _init_cpu_capabilities( void )
 {
-
-	_cpu_capabilities = 0;
+	_cpu_capabilities = _get_cpu_capabilities();
 }
