@@ -64,24 +64,52 @@
 #include <sys/syslimits.h>
 
 #if !defined(_ANSI_SOURCE)
+#define _POSIX_AIO_LISTIO_MAX   16
+#define _POSIX_AIO_MAX          1
+#define _POSIX_DELAYTIMER_MAX   32
+#define _POSIX_HOST_NAME_MAX    255
+#define _POSIX_LOGIN_NAME_MAX   9
+#define _POSIX_MQ_OPEN_MAX      8
+#define _POSIX_MQ_PRIO_MAX	32
+
 #define	_POSIX_ARG_MAX		4096
-#define	_POSIX_CHILD_MAX	6
+#define	_POSIX_CHILD_MAX	25
 #define	_POSIX_LINK_MAX		8
 #define	_POSIX_MAX_CANON	255
 #define	_POSIX_MAX_INPUT	255
 #define	_POSIX_NAME_MAX		14
-#define	_POSIX_NGROUPS_MAX	0
-#define	_POSIX_OPEN_MAX		16
-#define	_POSIX_PATH_MAX		255
+#define	_POSIX_NGROUPS_MAX	8
+#define	_POSIX_OPEN_MAX		20
+#define	_POSIX_PATH_MAX		256
 #define	_POSIX_PIPE_BUF		512
 #define	_POSIX_SSIZE_MAX	32767
 #define	_POSIX_STREAM_MAX	8
-#define	_POSIX_TZNAME_MAX	3
+#define	_POSIX_TZNAME_MAX	6
+
+#define _POSIX_RTSIG_MAX 			8
+#define _POSIX_SEM_NSEMS_MAX 			256
+#define _POSIX_SEM_VALUE_MAX 			32767
+#define _POSIX_SIGQUEUE_MAX 			32
+#define _POSIX_SSIZE_MAX 			32767
+#define _POSIX_STREAM_MAX 			8
+#define _POSIX_SS_REPL_MAX 			4
+#define _POSIX_SYMLINK_MAX 			255
+#define _POSIX_SYMLOOP_MAX 			8
+#define _POSIX_THREAD_DESTRUCTOR_ITERATIONS 	4
+#define _POSIX_THREAD_KEYS_MAX 			128
+#define _POSIX_THREAD_THREADS_MAX 		64
+#define _POSIX_TIMER_MAX 			32
+#define _POSIX_TRACE_EVENT_NAME_MAX 		30
+#define _POSIX_TRACE_NAME_MAX 			8
+#define _POSIX_TRACE_SYS_MAX 			8
+#define _POSIX_TRACE_USER_EVENT_MAX 		32
+#define _POSIX_TTY_NAME_MAX 			9
 
 #define	_POSIX2_BC_BASE_MAX		99
 #define	_POSIX2_BC_DIM_MAX		2048
 #define	_POSIX2_BC_SCALE_MAX		99
 #define	_POSIX2_BC_STRING_MAX		1000
+#define _POSIX2_CHARCLASS_NAME_MAX	14
 #define	_POSIX2_COLL_WEIGHTS_MAX	2
 #define	_POSIX2_EQUIV_CLASS_MAX		2
 #define	_POSIX2_EXPR_NEST_MAX		32
@@ -92,18 +120,25 @@
 #define PTHREAD_DESTRUCTOR_ITERATIONS 4
 #define PTHREAD_KEYS_MAX 128
 
-#endif /* !_ANSI_SOURCE */
-
-#if ( !defined(_ANSI_SOURCE) && !defined(_POSIX_SOURCE) ) || defined(_XOPEN_SOURCE)
+#if !defined(_POSIX_C_SOURCE)
 #define PASS_MAX	128
+#endif /* _POSIX_C_SOURCE */
 
 #define NL_ARGMAX	9
 #define NL_LANGMAX	14
 #define NL_MSGMAX	32767
 #define NL_NMAX		1
 #define NL_SETMAX	255
-#define NL_TEXTMAX	255
-#endif 
+#define NL_TEXTMAX	2048
 
+#define _XOPEN_IOV_MAX	16
+#define IOV_MAX		1024
+#define _XOPEN_NAME_MAX 255
+#define _XOPEN_PATH_MAX 1024
+
+#endif /* _ANSI_SOURCE */
+
+/* NZERO to be defined here. TBD. See also sys/param.h  */
 
 #endif /* !_LIMITS_H_ */
+
